@@ -69,7 +69,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.7.3-P1
+		echo VERSION=9.7.4-P1
 		exit 0
 		;;
 	--cflags)
@@ -143,7 +143,7 @@ if test x"$echo_libs" = x"true"; then
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -lcap "
+		libs="$libs  -lcap  -lxml2 -lz -lm"
 	fi
 	echo $libs
 fi
